Crate postgres_money

source ·
Dependencies

By default, this crate depends on the regex crate.

To activate JSON serialization via the serde crate, use syntax like:

[dependencies]
postgres_money = { version = "0.4", features = ["serde", "sql"] }

Visit the docs for Money for more info.

Structs

  • Representation of the Postgres ‘money’ type